@@ -397,7 +397,7 @@ EAction.prototype.showUiOptions = function(resume, restoreFromSettings) {
 
         // automatically add separator to toolbar:
         var a = optionsToolBar.addSeparator();
-        a.objectName = "LastSeparator";
+        a.objectName = "LastSeparator" + i;
         this.optionWidgetActions.push(a);
 
         // give action a chance to initialize toolbar widgets that cannot
@@ -1103,37 +1103,6 @@ EAction.getToolBar = function(title, objectName, toolBarArea, category, before)
 
     if (isNull(tb)) {
         tb = new QToolBar(title);
-
-        // style tool buttons in options toolbar:
-        if (RSettings.isQt(5)) {
-            if (!RSettings.hasCustomStyleSheet()) {
-                if (RSettings.hasDarkGuiBackground()) {
-                    tb.setStyleSheet(
-                          "QToolButton {"
-                             // make sure unchecked button renders with same size as checked
-                             // prevents things from moving around when checking / unchecking
-                        + "  border: 1px solid transparent;"
-                        + "} "
-                        + "QToolButton:checked { "
-                        + "  border-top: 1px solid #161616;"
-                        + "  border-left: 1px solid #161616;"
-                        + "  border-bottom: 1px solid #777777;"
-                        + "  border-right: 1px solid #777777;"
-                        + "  background-color: #222222;"
-                        + "}");
-                }
-                else {
-                    tb.setStyleSheet(
-                        "QToolButton {" +
-                        "  border: 1px solid transparent;" +
-                        "} " +
-                        "QToolButton:checked { " +
-                        "  border:1px solid #7f7f7f; " +
-                        "  background: qlineargradient(x1:0 y1:0, x2:0 y2:1 stop:0 #c0c0c0, stop:0.1 #8a8a8a stop:0.2 #a3a3a3 stop:1 transparent); " +
-                        "}");
-                }
-            }
-        }
         tb.objectName = objectName;
         if (!isNull(category)) {
             tb.setProperty("Category", category);
@@ -1391,6 +1360,8 @@ EAction.addGuiActionTo = function(action, iface, addToMenu, addToToolBar,
     if (isNull(addSeparator)) {
         addSeparator = false;
     }
+    var addToUserToolBar1 = false;
+    var addToUserToolBar2 = false;
 
     if (className.length!==0) {
         var key = className + "/VisibleInMenu";
@@ -1408,6 +1379,16 @@ EAction.addGuiActionTo = function(action, iface, addToMenu, addToToolBar,
         if (!RSettings.hasValue(key)) {
             RSettings.setValue(key, addToCadToolBar);
         }
+        key = className + "/VisibleInUserToolBar1";
+        addToUserToolBar1 = RSettings.getBoolValue(key, addToUserToolBar1);
+        if (!RSettings.hasValue(key)) {
+            RSettings.setValue(key, addToUserToolBar1);
+        }
+        key = className + "/VisibleInUserToolBar2";
+        addToUserToolBar2 = RSettings.getBoolValue(key, addToUserToolBar2);
+        if (!RSettings.hasValue(key)) {
+            RSettings.setValue(key, addToUserToolBar2);
+        }
     }
 
     if (isNull(iface)) {
@@ -1467,6 +1448,21 @@ EAction.addGuiActionTo = function(action, iface, addToMenu, addToToolBar,
             }
         }
     }
+
+    var appWin = EAction.getMainWindow();
+    if (addToUserToolBar1) {
+        var tb = appWin.findChild("UserToolBar1");
+        if (!isNull(tb)) {
+            action.addToToolBar(tb);
+        }
+    }
+
+    if (addToUserToolBar2) {
+        var tb = appWin.findChild("UserToolBar2");
+        if (!isNull(tb)) {
+            action.addToToolBar(tb);
+        }
+    }
 };
 
 //EAction.addGuiActionToWidgets = function(action, widgetNames) {
@@ -1770,6 +1766,13 @@ EAction.prototype.pickCoordinate = function(event, preview) {
  * Default implementation. Calls pickCoordinate(event, false)
  */
 EAction.prototype.coordinateEvent = function(event) {
+    // don't let invalid positions go through for most cases (this is overridden for DefaultAction):
+    var pos = event.getModelPosition();
+    if (!isValidVector(pos)) {
+        EAction.handleUserWarning(qsTr("Invalid position"));
+        return;
+    }
+
     this.pickCoordinate(event, false);
 };
 
