@@ -141,7 +141,7 @@ WidgetFactory.createDialog = function(basePath, uiFile, parent) {
     dialog.setWindowFlags(flags);
 
     // a global function might be defined to do additional
-    // initilization for all dialogs (e.g. for testing purposes):
+    // initialization for all dialogs (e.g. for testing purposes):
     if (typeof(initDialog)!=="undefined") {
         for (var i=0; i<initDialog.length; i++) {
             initDialog[i](dialog);
@@ -194,6 +194,31 @@ WidgetFactory.getKeyString = function(group, obj) {
     }
 };
 
+WidgetFactory.saveSize = function(widget) {
+    if (!widget) {
+        return;
+    }
+    var name = widget.objectName;
+    if (name.length===0) {
+        return;
+    }
+    RSettings.setValue(name + "/Width", widget.width);
+    RSettings.setValue(name + "/Height", widget.height);
+};
+
+WidgetFactory.restoreSize = function(widget) {
+    if (!widget) {
+        return;
+    }
+    var name = widget.objectName;
+    if (name.length===0) {
+        return;
+    }
+    var w = RSettings.getIntValue(name + "/Width", widget.width);
+    var h = RSettings.getIntValue(name + "/Height", widget.height);
+    widget.resize(w, h);
+};
+
 /**
  * Saves the current state of the given \c widget and all its child widgets.
  *
@@ -316,6 +341,9 @@ WidgetFactory.saveState = function(widget, group, document, map) {
         else if (isOfType(c, QSpinBox) || isOfType(c, QDoubleSpinBox)) {
             value = c.value;
         }
+        else if (isOfType(c, QSlider)) {
+            value = c.value;
+        }
         else if (isOfType(c, QListWidget)) {
             var items = [];
             if (c.count != 0) {
@@ -833,6 +861,24 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             continue;
         }
+        if (isOfType(c, QSlider)) {
+            WidgetFactory.connect(c["valueChanged(int)"], signalReceiver, c.objectName);
+            c["valueChanged(int)"].connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+
+            if (isNull(c.defaultValue)) {
+                c.defaultValue = c.value;
+                if (signalReceiver!=undefined) {
+                    f = signalReceiver["slot" + c.objectName + "Changed"];
+                    if (isFunction(f)) {
+                        f.call(signalReceiver, c.value);
+                    }
+                }
+            }
+            if (!isNull(value)) {
+                c.value = value;
+            }
+            continue;
+        }
         if (isOfType(c, QListWidget)) {
             // the SaveContents property is set to false
             // if the list contents should not be saved to
@@ -1175,19 +1221,40 @@ WidgetFactory.initTextBrowser = function(textBrowser, linkHandler, slot) {
 //    }
 //};
 
-WidgetFactory.initLayerCombo = function(comboBox, doc) {
+WidgetFactory.initLayerCombo = function(comboBox, doc, clear) {
+    var i;
+
     if (isNull(doc)) {
         return;
     }
+    if (isNull(clear)) {
+        clear = true;
+    }
+
+    var existingLayerNames = [];
+    if (clear) {
+        comboBox.clear();
+    }
+    else {
+        for (i=0; i<comboBox.count; i++) {
+            var t = comboBox.itemText(i);
+            existingLayerNames.push(t);
+        }
+    }
 
-    comboBox.clear();
     comboBox.iconSize = new QSize(16, 10);
     var names = doc.getLayerNames();
     //names = RS.sortAlphanumerical(names);
     names.sort(Array.alphaNumericalSorter);
-    for (var i=0; i<names.length; i++) {
+    for (i=0; i<names.length; i++) {
         var name = names[i];
         var layer = doc.queryLayer(name);
+
+        if (existingLayerNames.containsIgnoreCase(layer.getName())) {
+            // don't overwrite existing layers:
+            continue;
+        }
+
         var icon = RColor.getIcon(layer.getColor(), new QSize(comboBox.iconSize.width(),10));
         comboBox.addItem(icon, layer.getName());
     }
